@@ -1,10 +1,10 @@
 package Search::Elasticsearch::Client::0_90::Direct;
-$Search::Elasticsearch::Client::0_90::Direct::VERSION = '2.02';
+$Search::Elasticsearch::Client::0_90::Direct::VERSION = '2.03';
 use Moo;
 with 'Search::Elasticsearch::Role::API::0_90';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
-use Search::Elasticsearch::Util qw(parse_params load_plugin is_compat);
+use Search::Elasticsearch::Util qw(parse_params is_compat);
 use namespace::clean;
 
 has 'cluster'             => ( is => 'lazy' );
@@ -95,18 +95,6 @@ sub _build_cluster { shift->_build_namespace('Cluster') }
 sub _build_indices { shift->_build_namespace('Indices') }
 #===================================
 
-#===================================
-sub _build_namespace {
-#===================================
-    my ( $self, $ns ) = @_;
-    my $class = load_plugin( __PACKAGE__, [$ns] );
-    return $class->new(
-        {   transport => $self->transport,
-            logger    => $self->logger
-        }
-    );
-}
-
 1;
 
 =pod
@@ -119,7 +107,7 @@ Search::Elasticsearch::Client::0_90::Direct - Thin client with full support for
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 SYNOPSIS
 
