@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Error;
-$Search::Elasticsearch::Error::VERSION = '2.02';
+$Search::Elasticsearch::Error::VERSION = '2.03';
 our $DEBUG = 0;
 
 @Search::Elasticsearch::Error::Internal::ISA     = __PACKAGE__;
@@ -28,9 +28,15 @@ our $DEBUG = 0;
 @Search::Elasticsearch::Error::SSL::ISA
     = ( __PACKAGE__, 'Search::Elasticsearch::Error::Cxn' );
 
+@Search::Elasticsearch::Error::BadGateway::ISA
+    = ( 'Search::Elasticsearch::Error::Cxn', __PACKAGE__ );
+
 @Search::Elasticsearch::Error::Unavailable::ISA
     = ( 'Search::Elasticsearch::Error::Cxn', __PACKAGE__ );
 
+@Search::Elasticsearch::Error::GatewayTimeout::ISA
+    = ( 'Search::Elasticsearch::Error::Cxn', __PACKAGE__ );
+
 use overload (
     '""'  => '_stringify',
     'cmp' => '_compare',
@@ -82,8 +88,7 @@ sub _stringify {
     unless ( $self->{msg} ) {
         my $stack  = $self->{stack};
         my $caller = $stack->[0];
-        $self->{msg}
-            = sprintf( "[%s] ** %s, called from sub %s at %s line %d.",
+        $self->{msg} = sprintf( "[%s] ** %s, called from sub %s at %s line %d.",
             $self->{type}, $self->{text}, @{$caller}[ 3, 1, 2 ] );
 
         if ( $self->{vars} ) {
@@ -174,7 +179,7 @@ Search::Elasticsearch::Error - Errors thrown by Search::Elasticsearch
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 DESCRIPTION
 
@@ -264,6 +269,16 @@ The current node is unable to handle your request at the moment. Your
 request will be retried on another node.  This error is triggered by
 the C<503> HTTP status code.
 
+=item * C<Search::Elasticsearch::Error::BadGateway>
+
+A proxy between the client and Elasticsearch is unable to connect to Elasticsearch.
+This error is triggered by the C<502> HTTP status code.
+
+=item * C<Search::Elasticsearch::Error::GatewayTimeout>
+
+A proxy between the client and Elasticsearch is unable to connect to Elasticsearch
+within its own timeout. This error is triggered by the C<504> HTTP status code.
+
 =item * C<Search::Elasticsearch::Error::SSL>
 
 There was a problem validating the SSL certificate.  Not all
