@@ -1,8 +1,10 @@
 package Search::Elasticsearch::Role::Client::Direct;
-$Search::Elasticsearch::Role::Client::Direct::VERSION = '2.02';
+$Search::Elasticsearch::Role::Client::Direct::VERSION = '2.03';
 use Moo::Role;
 with 'Search::Elasticsearch::Role::Client';
 use Search::Elasticsearch::Util::API::Path qw(path_handler);
+use Search::Elasticsearch::Util qw(load_plugin);
+
 use Try::Tiny;
 use Package::Stash 0.34 ();
 use namespace::clean;
@@ -104,6 +106,18 @@ sub _install_api {
     }
 }
 
+#===================================
+sub _build_namespace {
+#===================================
+    my ( $self, $ns ) = @_;
+    my $class = load_plugin( $self->_namespace, [$ns] );
+    return $class->new(
+        {   transport => $self->transport,
+            logger    => $self->logger
+        }
+    );
+}
+
 1;
 
 # ABSTRACT: Request parsing for Direct clients
@@ -120,7 +134,7 @@ Search::Elasticsearch::Role::Client::Direct - Request parsing for Direct clients
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 DESCRIPTION
 
