@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Client::Direct::Main;
-$Search::Elasticsearch::Role::Client::Direct::Main::VERSION = '2.02';
+$Search::Elasticsearch::Role::Client::Direct::Main::VERSION = '2.03';
 use Moo::Role;
-requires '_namespace';
 
 use Search::Elasticsearch::Util qw(parse_params load_plugin is_compat);
 
@@ -73,18 +72,6 @@ sub _build_cat      { shift->_build_namespace('Cat') }
 sub _build_tasks    { shift->_build_namespace('Tasks') }
 #===================================
 
-#===================================
-sub _build_namespace {
-#===================================
-    my ( $self, $ns ) = @_;
-    my $class = load_plugin( $self->_namespace, [$ns] );
-    return $class->new(
-        {   transport => $self->transport,
-            logger    => $self->logger
-        }
-    );
-}
-
 1;
 
 =pod
@@ -97,7 +84,7 @@ Search::Elasticsearch::Role::Client::Direct::Main - Attributes and methods used
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 DESCRIPTION
 
