@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Cxn;
-$Search::Elasticsearch::Role::Cxn::VERSION = '2.02';
+$Search::Elasticsearch::Role::Cxn::VERSION = '2.03';
 use Moo::Role;
 use Search::Elasticsearch::Util qw(throw);
 use List::Util qw(min);
@@ -33,7 +33,9 @@ my %Code_To_Error = (
     404 => 'Missing',
     408 => 'RequestTimeout',
     409 => 'Conflict',
-    503 => 'Unavailable'
+    502 => 'BadGateway',
+    503 => 'Unavailable',
+    504 => 'GatewayTimeout'
 );
 
 #===================================
@@ -216,7 +218,7 @@ Search::Elasticsearch::Role::Cxn - Provides common functionality to Cxn implemen
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 DESCRIPTION
 
