@@ -1,9 +1,9 @@
 package Search::Elasticsearch::Util::API::QS;
-$Search::Elasticsearch::Util::API::QS::VERSION = '2.02';
+$Search::Elasticsearch::Util::API::QS::VERSION = '2.03';
 use strict;
 use warnings;
 
-use Sub::Exporter -setup => { exports => ['qs_init'] };
+use Sub::Exporter -setup => { exports => [ 'qs_init', 'register_qs' ] };
 
 our %Handler = (
     string => sub {"$_[0]"},
@@ -291,6 +291,18 @@ sub qs_init {
     return \%qs;
 }
 
+#===================================
+sub register_qs {
+#===================================
+    while (@_) {
+        my $key = shift;
+        die "Query string parameter ($key) already exists"
+            if $Params{$key};
+        my $handler = shift
+            || die "No handler provided for query string parameter ($key)";
+        $Params{$key} = $handler;
+    }
+}
 1;
 
 =pod
@@ -303,7 +315,7 @@ Search::Elasticsearch::Util::API::QS - A utility class for query string paramete
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 DESCRIPTION
 
@@ -333,6 +345,14 @@ Would result in:
     $qs_hash: { fields => 'foo,bar', size => 10};
     $params:   { query => \%query }
 
+=head2 C<register_qs()>
+
+    use Search::Elasticsearch::Util::API::QS qw(register_qs);
+
+    register_qs( foo => { type => 'bool'},...)
+
+Allows plugins to add query string parameter handlers.
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
