@@ -3,7 +3,9 @@ use warnings;
 use Search::Elasticsearch::Bulk;
 use lib 't/lib';
 
-my $es = do 'es_sync.pl';
+local $ENV{ES_CXN};
+local $ENV{ES_CXN_POOL};
+my $es = do 'es_sync.pl' or die( $@ || $! );
 
 $es->indices->delete( index => 'test', ignore => 404 );
 $es->indices->create( index => 'test' );
